##  Step 1: Update the Tech Category Hierarchy
Change the parent tech category for the following fact sheets:
Current and New Parent Tech Categories Tech Category Fact Sheet | Current Parent Tech Category | New Parent Tech Category
---|---|---
Data | Platform | Infrastructure
Application | Platform | Delivery


After updating the hierarchy, the display names of these fact sheets change as follows:
Previous and New Display Names of Tech Categories Previous Display Name | New Display Name
---|---
Platform / Data | Infrastructure / Data
Platform / Application | Delivery / Application


